@@ -104,11 +104,6 @@ def list_to_dict(l):
     return d
 
 
-def get_filename(file):
-    ''' 获取文件名 '''
-    return file[:file.find('.')]
-
-
 def paramToDict(parameters, place=PLACE.GET, hint=POST_HINT.NORMAL) -> dict:
     """
     Split the parameters into names and values, check if these parameters
